Module session

Module session 

Session management for the Copilot SDK.

A session represents a conversation with the Copilot CLI.

Structs

EventSubscription
A subscription to session events.
RegisteredTool
A tool registered with the session, including its handler.
Session
A Copilot conversation session.

Type Aliases

EventHandler
Handler for session events.
InvokeFuture
Type alias for the invoke future.
PermissionHandler
Handler for permission requests.
ToolHandler
Handler for tool invocations.
UserInputHandler
Handler for user input requests.