Session management for the Copilot SDK.
A session represents a conversation with the Copilot CLI.
Structs
- Event
Subscription - A subscription to session events.
- Registered
Tool - A tool registered with the session, including its handler.
- Session
- A Copilot conversation session.
Type Aliases
- Event
Handler - Handler for session events.
- Invoke
Future - Type alias for the invoke future.
- Permission
Handler - Handler for permission requests.
- Tool
Handler - Handler for tool invocations.
- User
Input Handler - Handler for user input requests.